"""This module contains the general information for ProcessorMiscStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ProcessorMiscStatsConsts:
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ProcessorMiscStats(ManagedObject):
    """This is ProcessorMiscStats class."""

    consts = ProcessorMiscStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcessorMiscStats", "processorMiscStats", "misc-stats", VersionMeta.Version412a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['processorUnit'], [], [None])

    prop_meta = {
        "coherent_slave_correctable_errors": MoPropertyMeta("coherent_slave_correctable_errors", "CoherentSlaveCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors15_min": MoPropertyMeta("coherent_slave_correctable_errors15_min", "CoherentSlaveCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors15_min_h": MoPropertyMeta("coherent_slave_correctable_errors15_min_h", "CoherentSlaveCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors1_day": MoPropertyMeta("coherent_slave_correctable_errors1_day", "CoherentSlaveCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors1_day_h": MoPropertyMeta("coherent_slave_correctable_errors1_day_h", "CoherentSlaveCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors1_hour": MoPropertyMeta("coherent_slave_correctable_errors1_hour", "CoherentSlaveCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors1_hour_h": MoPropertyMeta("coherent_slave_correctable_errors1_hour_h", "CoherentSlaveCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors1_week": MoPropertyMeta("coherent_slave_correctable_errors1_week", "CoherentSlaveCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors1_week_h": MoPropertyMeta("coherent_slave_correctable_errors1_week_h", "CoherentSlaveCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors2_weeks": MoPropertyMeta("coherent_slave_correctable_errors2_weeks", "CoherentSlaveCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_correctable_errors2_weeks_h": MoPropertyMeta("coherent_slave_correctable_errors2_weeks_h", "CoherentSlaveCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors": MoPropertyMeta("coherent_slave_uncorrectable_errors", "CoherentSlaveUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors15_min": MoPropertyMeta("coherent_slave_uncorrectable_errors15_min", "CoherentSlaveUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors15_min_h": MoPropertyMeta("coherent_slave_uncorrectable_errors15_min_h", "CoherentSlaveUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors1_day": MoPropertyMeta("coherent_slave_uncorrectable_errors1_day", "CoherentSlaveUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors1_day_h": MoPropertyMeta("coherent_slave_uncorrectable_errors1_day_h", "CoherentSlaveUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors1_hour": MoPropertyMeta("coherent_slave_uncorrectable_errors1_hour", "CoherentSlaveUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors1_hour_h": MoPropertyMeta("coherent_slave_uncorrectable_errors1_hour_h", "CoherentSlaveUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors1_week": MoPropertyMeta("coherent_slave_uncorrectable_errors1_week", "CoherentSlaveUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors1_week_h": MoPropertyMeta("coherent_slave_uncorrectable_errors1_week_h", "CoherentSlaveUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors2_weeks": MoPropertyMeta("coherent_slave_uncorrectable_errors2_weeks", "CoherentSlaveUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "coherent_slave_uncorrectable_errors2_weeks_h": MoPropertyMeta("coherent_slave_uncorrectable_errors2_weeks_h", "CoherentSlaveUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors": MoPropertyMeta("floating_point_unit_correctable_errors", "FloatingPointUnitCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors15_min": MoPropertyMeta("floating_point_unit_correctable_errors15_min", "FloatingPointUnitCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors15_min_h": MoPropertyMeta("floating_point_unit_correctable_errors15_min_h", "FloatingPointUnitCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors1_day": MoPropertyMeta("floating_point_unit_correctable_errors1_day", "FloatingPointUnitCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors1_day_h": MoPropertyMeta("floating_point_unit_correctable_errors1_day_h", "FloatingPointUnitCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors1_hour": MoPropertyMeta("floating_point_unit_correctable_errors1_hour", "FloatingPointUnitCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors1_hour_h": MoPropertyMeta("floating_point_unit_correctable_errors1_hour_h", "FloatingPointUnitCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors1_week": MoPropertyMeta("floating_point_unit_correctable_errors1_week", "FloatingPointUnitCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors1_week_h": MoPropertyMeta("floating_point_unit_correctable_errors1_week_h", "FloatingPointUnitCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors2_weeks": MoPropertyMeta("floating_point_unit_correctable_errors2_weeks", "FloatingPointUnitCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_correctable_errors2_weeks_h": MoPropertyMeta("floating_point_unit_correctable_errors2_weeks_h", "FloatingPointUnitCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors": MoPropertyMeta("floating_point_unit_uncorrectable_errors", "FloatingPointUnitUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors15_min": MoPropertyMeta("floating_point_unit_uncorrectable_errors15_min", "FloatingPointUnitUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors15_min_h": MoPropertyMeta("floating_point_unit_uncorrectable_errors15_min_h", "FloatingPointUnitUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors1_day": MoPropertyMeta("floating_point_unit_uncorrectable_errors1_day", "FloatingPointUnitUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors1_day_h": MoPropertyMeta("floating_point_unit_uncorrectable_errors1_day_h", "FloatingPointUnitUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors1_hour": MoPropertyMeta("floating_point_unit_uncorrectable_errors1_hour", "FloatingPointUnitUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors1_hour_h": MoPropertyMeta("floating_point_unit_uncorrectable_errors1_hour_h", "FloatingPointUnitUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors1_week": MoPropertyMeta("floating_point_unit_uncorrectable_errors1_week", "FloatingPointUnitUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors1_week_h": MoPropertyMeta("floating_point_unit_uncorrectable_errors1_week_h", "FloatingPointUnitUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors2_weeks": MoPropertyMeta("floating_point_unit_uncorrectable_errors2_weeks", "FloatingPointUnitUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "floating_point_unit_uncorrectable_errors2_weeks_h": MoPropertyMeta("floating_point_unit_uncorrectable_errors2_weeks_h", "FloatingPointUnitUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors": MoPropertyMeta("mp_mgmnt_controller_correctable_errors", "MPMgmntControllerCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors15_min": MoPropertyMeta("mp_mgmnt_controller_correctable_errors15_min", "MPMgmntControllerCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors15_min_h": MoPropertyMeta("mp_mgmnt_controller_correctable_errors15_min_h", "MPMgmntControllerCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors1_day": MoPropertyMeta("mp_mgmnt_controller_correctable_errors1_day", "MPMgmntControllerCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors1_day_h": MoPropertyMeta("mp_mgmnt_controller_correctable_errors1_day_h", "MPMgmntControllerCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors1_hour": MoPropertyMeta("mp_mgmnt_controller_correctable_errors1_hour", "MPMgmntControllerCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors1_hour_h": MoPropertyMeta("mp_mgmnt_controller_correctable_errors1_hour_h", "MPMgmntControllerCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors1_week": MoPropertyMeta("mp_mgmnt_controller_correctable_errors1_week", "MPMgmntControllerCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors1_week_h": MoPropertyMeta("mp_mgmnt_controller_correctable_errors1_week_h", "MPMgmntControllerCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors2_weeks": MoPropertyMeta("mp_mgmnt_controller_correctable_errors2_weeks", "MPMgmntControllerCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_correctable_errors2_weeks_h": MoPropertyMeta("mp_mgmnt_controller_correctable_errors2_weeks_h", "MPMgmntControllerCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors", "MPMgmntControllerUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors15_min": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors15_min", "MPMgmntControllerUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors15_min_h": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors15_min_h", "MPMgmntControllerUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors1_day": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors1_day", "MPMgmntControllerUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors1_day_h": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors1_day_h", "MPMgmntControllerUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors1_hour": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors1_hour", "MPMgmntControllerUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors1_hour_h": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors1_hour_h", "MPMgmntControllerUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors1_week": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors1_week", "MPMgmntControllerUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors1_week_h": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors1_week_h", "MPMgmntControllerUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors2_weeks": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors2_weeks", "MPMgmntControllerUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mp_mgmnt_controller_uncorrectable_errors2_weeks_h": MoPropertyMeta("mp_mgmnt_controller_uncorrectable_errors2_weeks_h", "MPMgmntControllerUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors": MoPropertyMeta("parameter_block_correctable_errors", "ParameterBlockCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors15_min": MoPropertyMeta("parameter_block_correctable_errors15_min", "ParameterBlockCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors15_min_h": MoPropertyMeta("parameter_block_correctable_errors15_min_h", "ParameterBlockCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors1_day": MoPropertyMeta("parameter_block_correctable_errors1_day", "ParameterBlockCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors1_day_h": MoPropertyMeta("parameter_block_correctable_errors1_day_h", "ParameterBlockCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors1_hour": MoPropertyMeta("parameter_block_correctable_errors1_hour", "ParameterBlockCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors1_hour_h": MoPropertyMeta("parameter_block_correctable_errors1_hour_h", "ParameterBlockCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors1_week": MoPropertyMeta("parameter_block_correctable_errors1_week", "ParameterBlockCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors1_week_h": MoPropertyMeta("parameter_block_correctable_errors1_week_h", "ParameterBlockCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors2_weeks": MoPropertyMeta("parameter_block_correctable_errors2_weeks", "ParameterBlockCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_correctable_errors2_weeks_h": MoPropertyMeta("parameter_block_correctable_errors2_weeks_h", "ParameterBlockCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors": MoPropertyMeta("parameter_block_uncorrectable_errors", "ParameterBlockUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors15_min": MoPropertyMeta("parameter_block_uncorrectable_errors15_min", "ParameterBlockUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors15_min_h": MoPropertyMeta("parameter_block_uncorrectable_errors15_min_h", "ParameterBlockUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors1_day": MoPropertyMeta("parameter_block_uncorrectable_errors1_day", "ParameterBlockUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors1_day_h": MoPropertyMeta("parameter_block_uncorrectable_errors1_day_h", "ParameterBlockUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors1_hour": MoPropertyMeta("parameter_block_uncorrectable_errors1_hour", "ParameterBlockUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors1_hour_h": MoPropertyMeta("parameter_block_uncorrectable_errors1_hour_h", "ParameterBlockUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors1_week": MoPropertyMeta("parameter_block_uncorrectable_errors1_week", "ParameterBlockUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors1_week_h": MoPropertyMeta("parameter_block_uncorrectable_errors1_week_h", "ParameterBlockUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors2_weeks": MoPropertyMeta("parameter_block_uncorrectable_errors2_weeks", "ParameterBlockUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "parameter_block_uncorrectable_errors2_weeks_h": MoPropertyMeta("parameter_block_uncorrectable_errors2_weeks_h", "ParameterBlockUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version412a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version412a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "CoherentSlaveCorrectableErrors": "coherent_slave_correctable_errors", 
        "CoherentSlaveCorrectableErrors15Min": "coherent_slave_correctable_errors15_min", 
        "CoherentSlaveCorrectableErrors15MinH": "coherent_slave_correctable_errors15_min_h", 
        "CoherentSlaveCorrectableErrors1Day": "coherent_slave_correctable_errors1_day", 
        "CoherentSlaveCorrectableErrors1DayH": "coherent_slave_correctable_errors1_day_h", 
        "CoherentSlaveCorrectableErrors1Hour": "coherent_slave_correctable_errors1_hour", 
        "CoherentSlaveCorrectableErrors1HourH": "coherent_slave_correctable_errors1_hour_h", 
        "CoherentSlaveCorrectableErrors1Week": "coherent_slave_correctable_errors1_week", 
        "CoherentSlaveCorrectableErrors1WeekH": "coherent_slave_correctable_errors1_week_h", 
        "CoherentSlaveCorrectableErrors2Weeks": "coherent_slave_correctable_errors2_weeks", 
        "CoherentSlaveCorrectableErrors2WeeksH": "coherent_slave_correctable_errors2_weeks_h", 
        "CoherentSlaveUncorrectableErrors": "coherent_slave_uncorrectable_errors", 
        "CoherentSlaveUncorrectableErrors15Min": "coherent_slave_uncorrectable_errors15_min", 
        "CoherentSlaveUncorrectableErrors15MinH": "coherent_slave_uncorrectable_errors15_min_h", 
        "CoherentSlaveUncorrectableErrors1Day": "coherent_slave_uncorrectable_errors1_day", 
        "CoherentSlaveUncorrectableErrors1DayH": "coherent_slave_uncorrectable_errors1_day_h", 
        "CoherentSlaveUncorrectableErrors1Hour": "coherent_slave_uncorrectable_errors1_hour", 
        "CoherentSlaveUncorrectableErrors1HourH": "coherent_slave_uncorrectable_errors1_hour_h", 
        "CoherentSlaveUncorrectableErrors1Week": "coherent_slave_uncorrectable_errors1_week", 
        "CoherentSlaveUncorrectableErrors1WeekH": "coherent_slave_uncorrectable_errors1_week_h", 
        "CoherentSlaveUncorrectableErrors2Weeks": "coherent_slave_uncorrectable_errors2_weeks", 
        "CoherentSlaveUncorrectableErrors2WeeksH": "coherent_slave_uncorrectable_errors2_weeks_h", 
        "FloatingPointUnitCorrectableErrors": "floating_point_unit_correctable_errors", 
        "FloatingPointUnitCorrectableErrors15Min": "floating_point_unit_correctable_errors15_min", 
        "FloatingPointUnitCorrectableErrors15MinH": "floating_point_unit_correctable_errors15_min_h", 
        "FloatingPointUnitCorrectableErrors1Day": "floating_point_unit_correctable_errors1_day", 
        "FloatingPointUnitCorrectableErrors1DayH": "floating_point_unit_correctable_errors1_day_h", 
        "FloatingPointUnitCorrectableErrors1Hour": "floating_point_unit_correctable_errors1_hour", 
        "FloatingPointUnitCorrectableErrors1HourH": "floating_point_unit_correctable_errors1_hour_h", 
        "FloatingPointUnitCorrectableErrors1Week": "floating_point_unit_correctable_errors1_week", 
        "FloatingPointUnitCorrectableErrors1WeekH": "floating_point_unit_correctable_errors1_week_h", 
        "FloatingPointUnitCorrectableErrors2Weeks": "floating_point_unit_correctable_errors2_weeks", 
        "FloatingPointUnitCorrectableErrors2WeeksH": "floating_point_unit_correctable_errors2_weeks_h", 
        "FloatingPointUnitUncorrectableErrors": "floating_point_unit_uncorrectable_errors", 
        "FloatingPointUnitUncorrectableErrors15Min": "floating_point_unit_uncorrectable_errors15_min", 
        "FloatingPointUnitUncorrectableErrors15MinH": "floating_point_unit_uncorrectable_errors15_min_h", 
        "FloatingPointUnitUncorrectableErrors1Day": "floating_point_unit_uncorrectable_errors1_day", 
        "FloatingPointUnitUncorrectableErrors1DayH": "floating_point_unit_uncorrectable_errors1_day_h", 
        "FloatingPointUnitUncorrectableErrors1Hour": "floating_point_unit_uncorrectable_errors1_hour", 
        "FloatingPointUnitUncorrectableErrors1HourH": "floating_point_unit_uncorrectable_errors1_hour_h", 
        "FloatingPointUnitUncorrectableErrors1Week": "floating_point_unit_uncorrectable_errors1_week", 
        "FloatingPointUnitUncorrectableErrors1WeekH": "floating_point_unit_uncorrectable_errors1_week_h", 
        "FloatingPointUnitUncorrectableErrors2Weeks": "floating_point_unit_uncorrectable_errors2_weeks", 
        "FloatingPointUnitUncorrectableErrors2WeeksH": "floating_point_unit_uncorrectable_errors2_weeks_h", 
        "MPMgmntControllerCorrectableErrors": "mp_mgmnt_controller_correctable_errors", 
        "MPMgmntControllerCorrectableErrors15Min": "mp_mgmnt_controller_correctable_errors15_min", 
        "MPMgmntControllerCorrectableErrors15MinH": "mp_mgmnt_controller_correctable_errors15_min_h", 
        "MPMgmntControllerCorrectableErrors1Day": "mp_mgmnt_controller_correctable_errors1_day", 
        "MPMgmntControllerCorrectableErrors1DayH": "mp_mgmnt_controller_correctable_errors1_day_h", 
        "MPMgmntControllerCorrectableErrors1Hour": "mp_mgmnt_controller_correctable_errors1_hour", 
        "MPMgmntControllerCorrectableErrors1HourH": "mp_mgmnt_controller_correctable_errors1_hour_h", 
        "MPMgmntControllerCorrectableErrors1Week": "mp_mgmnt_controller_correctable_errors1_week", 
        "MPMgmntControllerCorrectableErrors1WeekH": "mp_mgmnt_controller_correctable_errors1_week_h", 
        "MPMgmntControllerCorrectableErrors2Weeks": "mp_mgmnt_controller_correctable_errors2_weeks", 
        "MPMgmntControllerCorrectableErrors2WeeksH": "mp_mgmnt_controller_correctable_errors2_weeks_h", 
        "MPMgmntControllerUncorrectableErrors": "mp_mgmnt_controller_uncorrectable_errors", 
        "MPMgmntControllerUncorrectableErrors15Min": "mp_mgmnt_controller_uncorrectable_errors15_min", 
        "MPMgmntControllerUncorrectableErrors15MinH": "mp_mgmnt_controller_uncorrectable_errors15_min_h", 
        "MPMgmntControllerUncorrectableErrors1Day": "mp_mgmnt_controller_uncorrectable_errors1_day", 
        "MPMgmntControllerUncorrectableErrors1DayH": "mp_mgmnt_controller_uncorrectable_errors1_day_h", 
        "MPMgmntControllerUncorrectableErrors1Hour": "mp_mgmnt_controller_uncorrectable_errors1_hour", 
        "MPMgmntControllerUncorrectableErrors1HourH": "mp_mgmnt_controller_uncorrectable_errors1_hour_h", 
        "MPMgmntControllerUncorrectableErrors1Week": "mp_mgmnt_controller_uncorrectable_errors1_week", 
        "MPMgmntControllerUncorrectableErrors1WeekH": "mp_mgmnt_controller_uncorrectable_errors1_week_h", 
        "MPMgmntControllerUncorrectableErrors2Weeks": "mp_mgmnt_controller_uncorrectable_errors2_weeks", 
        "MPMgmntControllerUncorrectableErrors2WeeksH": "mp_mgmnt_controller_uncorrectable_errors2_weeks_h", 
        "ParameterBlockCorrectableErrors": "parameter_block_correctable_errors", 
        "ParameterBlockCorrectableErrors15Min": "parameter_block_correctable_errors15_min", 
        "ParameterBlockCorrectableErrors15MinH": "parameter_block_correctable_errors15_min_h", 
        "ParameterBlockCorrectableErrors1Day": "parameter_block_correctable_errors1_day", 
        "ParameterBlockCorrectableErrors1DayH": "parameter_block_correctable_errors1_day_h", 
        "ParameterBlockCorrectableErrors1Hour": "parameter_block_correctable_errors1_hour", 
        "ParameterBlockCorrectableErrors1HourH": "parameter_block_correctable_errors1_hour_h", 
        "ParameterBlockCorrectableErrors1Week": "parameter_block_correctable_errors1_week", 
        "ParameterBlockCorrectableErrors1WeekH": "parameter_block_correctable_errors1_week_h", 
        "ParameterBlockCorrectableErrors2Weeks": "parameter_block_correctable_errors2_weeks", 
        "ParameterBlockCorrectableErrors2WeeksH": "parameter_block_correctable_errors2_weeks_h", 
        "ParameterBlockUncorrectableErrors": "parameter_block_uncorrectable_errors", 
        "ParameterBlockUncorrectableErrors15Min": "parameter_block_uncorrectable_errors15_min", 
        "ParameterBlockUncorrectableErrors15MinH": "parameter_block_uncorrectable_errors15_min_h", 
        "ParameterBlockUncorrectableErrors1Day": "parameter_block_uncorrectable_errors1_day", 
        "ParameterBlockUncorrectableErrors1DayH": "parameter_block_uncorrectable_errors1_day_h", 
        "ParameterBlockUncorrectableErrors1Hour": "parameter_block_uncorrectable_errors1_hour", 
        "ParameterBlockUncorrectableErrors1HourH": "parameter_block_uncorrectable_errors1_hour_h", 
        "ParameterBlockUncorrectableErrors1Week": "parameter_block_uncorrectable_errors1_week", 
        "ParameterBlockUncorrectableErrors1WeekH": "parameter_block_uncorrectable_errors1_week_h", 
        "ParameterBlockUncorrectableErrors2Weeks": "parameter_block_uncorrectable_errors2_weeks", 
        "ParameterBlockUncorrectableErrors2WeeksH": "parameter_block_uncorrectable_errors2_weeks_h", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.coherent_slave_correctable_errors = None
        self.coherent_slave_correctable_errors15_min = None
        self.coherent_slave_correctable_errors15_min_h = None
        self.coherent_slave_correctable_errors1_day = None
        self.coherent_slave_correctable_errors1_day_h = None
        self.coherent_slave_correctable_errors1_hour = None
        self.coherent_slave_correctable_errors1_hour_h = None
        self.coherent_slave_correctable_errors1_week = None
        self.coherent_slave_correctable_errors1_week_h = None
        self.coherent_slave_correctable_errors2_weeks = None
        self.coherent_slave_correctable_errors2_weeks_h = None
        self.coherent_slave_uncorrectable_errors = None
        self.coherent_slave_uncorrectable_errors15_min = None
        self.coherent_slave_uncorrectable_errors15_min_h = None
        self.coherent_slave_uncorrectable_errors1_day = None
        self.coherent_slave_uncorrectable_errors1_day_h = None
        self.coherent_slave_uncorrectable_errors1_hour = None
        self.coherent_slave_uncorrectable_errors1_hour_h = None
        self.coherent_slave_uncorrectable_errors1_week = None
        self.coherent_slave_uncorrectable_errors1_week_h = None
        self.coherent_slave_uncorrectable_errors2_weeks = None
        self.coherent_slave_uncorrectable_errors2_weeks_h = None
        self.floating_point_unit_correctable_errors = None
        self.floating_point_unit_correctable_errors15_min = None
        self.floating_point_unit_correctable_errors15_min_h = None
        self.floating_point_unit_correctable_errors1_day = None
        self.floating_point_unit_correctable_errors1_day_h = None
        self.floating_point_unit_correctable_errors1_hour = None
        self.floating_point_unit_correctable_errors1_hour_h = None
        self.floating_point_unit_correctable_errors1_week = None
        self.floating_point_unit_correctable_errors1_week_h = None
        self.floating_point_unit_correctable_errors2_weeks = None
        self.floating_point_unit_correctable_errors2_weeks_h = None
        self.floating_point_unit_uncorrectable_errors = None
        self.floating_point_unit_uncorrectable_errors15_min = None
        self.floating_point_unit_uncorrectable_errors15_min_h = None
        self.floating_point_unit_uncorrectable_errors1_day = None
        self.floating_point_unit_uncorrectable_errors1_day_h = None
        self.floating_point_unit_uncorrectable_errors1_hour = None
        self.floating_point_unit_uncorrectable_errors1_hour_h = None
        self.floating_point_unit_uncorrectable_errors1_week = None
        self.floating_point_unit_uncorrectable_errors1_week_h = None
        self.floating_point_unit_uncorrectable_errors2_weeks = None
        self.floating_point_unit_uncorrectable_errors2_weeks_h = None
        self.mp_mgmnt_controller_correctable_errors = None
        self.mp_mgmnt_controller_correctable_errors15_min = None
        self.mp_mgmnt_controller_correctable_errors15_min_h = None
        self.mp_mgmnt_controller_correctable_errors1_day = None
        self.mp_mgmnt_controller_correctable_errors1_day_h = None
        self.mp_mgmnt_controller_correctable_errors1_hour = None
        self.mp_mgmnt_controller_correctable_errors1_hour_h = None
        self.mp_mgmnt_controller_correctable_errors1_week = None
        self.mp_mgmnt_controller_correctable_errors1_week_h = None
        self.mp_mgmnt_controller_correctable_errors2_weeks = None
        self.mp_mgmnt_controller_correctable_errors2_weeks_h = None
        self.mp_mgmnt_controller_uncorrectable_errors = None
        self.mp_mgmnt_controller_uncorrectable_errors15_min = None
        self.mp_mgmnt_controller_uncorrectable_errors15_min_h = None
        self.mp_mgmnt_controller_uncorrectable_errors1_day = None
        self.mp_mgmnt_controller_uncorrectable_errors1_day_h = None
        self.mp_mgmnt_controller_uncorrectable_errors1_hour = None
        self.mp_mgmnt_controller_uncorrectable_errors1_hour_h = None
        self.mp_mgmnt_controller_uncorrectable_errors1_week = None
        self.mp_mgmnt_controller_uncorrectable_errors1_week_h = None
        self.mp_mgmnt_controller_uncorrectable_errors2_weeks = None
        self.mp_mgmnt_controller_uncorrectable_errors2_weeks_h = None
        self.parameter_block_correctable_errors = None
        self.parameter_block_correctable_errors15_min = None
        self.parameter_block_correctable_errors15_min_h = None
        self.parameter_block_correctable_errors1_day = None
        self.parameter_block_correctable_errors1_day_h = None
        self.parameter_block_correctable_errors1_hour = None
        self.parameter_block_correctable_errors1_hour_h = None
        self.parameter_block_correctable_errors1_week = None
        self.parameter_block_correctable_errors1_week_h = None
        self.parameter_block_correctable_errors2_weeks = None
        self.parameter_block_correctable_errors2_weeks_h = None
        self.parameter_block_uncorrectable_errors = None
        self.parameter_block_uncorrectable_errors15_min = None
        self.parameter_block_uncorrectable_errors15_min_h = None
        self.parameter_block_uncorrectable_errors1_day = None
        self.parameter_block_uncorrectable_errors1_day_h = None
        self.parameter_block_uncorrectable_errors1_hour = None
        self.parameter_block_uncorrectable_errors1_hour_h = None
        self.parameter_block_uncorrectable_errors1_week = None
        self.parameter_block_uncorrectable_errors1_week_h = None
        self.parameter_block_uncorrectable_errors2_weeks = None
        self.parameter_block_uncorrectable_errors2_weeks_h = None
        self.child_action = None
        self.intervals = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ProcessorMiscStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for SwVlanPortNs ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SwVlanPortNsConsts:
    ALLOC_STATUS_AVAILABLE = "available"
    ALLOC_STATUS_EXCEEDED = "exceeded"
    COMPRESSED_OPTIMIZATION_SETS_NA = "NA"
    COMPRESSED_VLAN_PORT_COUNT_NA = "NA"
    CONFIG_STATUS_NO_VLAN_COMP = "no-vlan-comp"
    CONFIG_STATUS_NONE = "none"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"
    TOTAL_OPTIMIZATION_SETS_NA = "NA"
    UNCOMPRESSED_VLAN_PORT_COUNT_NA = "NA"


class SwVlanPortNs(ManagedObject):
    """This is SwVlanPortNs class."""

    consts = SwVlanPortNsConsts()
    naming_props = set([])

    mo_meta = MoMeta("SwVlanPortNs", "swVlanPortNs", "vlan-port-ns", VersionMeta.Version131c, "InputOutput", 0x1f, [], ["read-only"], ['networkElement'], ['faultInst'], ["Get"])

    prop_meta = {
        "access_vlan_port_count": MoPropertyMeta("access_vlan_port_count", "accessVlanPortCount", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "alloc_status": MoPropertyMeta("alloc_status", "allocStatus", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["available", "exceeded"], []),
        "border_vlan_port_count": MoPropertyMeta("border_vlan_port_count", "borderVlanPortCount", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131c, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "compressed_optimization_sets": MoPropertyMeta("compressed_optimization_sets", "compressedOptimizationSets", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]),
        "compressed_vlan_port_count": MoPropertyMeta("compressed_vlan_port_count", "compressedVlanPortCount", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]),
        "config_status": MoPropertyMeta("config_status", "configStatus", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no-vlan-comp", "none"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "limit": MoPropertyMeta("limit", "limit", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE"], []),
        "total_optimization_sets": MoPropertyMeta("total_optimization_sets", "totalOptimizationSets", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]),
        "total_vlan_port_count": MoPropertyMeta("total_vlan_port_count", "totalVlanPortCount", "uint", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "uncompressed_vlan_port_count": MoPropertyMeta("uncompressed_vlan_port_count", "uncompressedVlanPortCount", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]),
        "vlan_comp_off_limit": MoPropertyMeta("vlan_comp_off_limit", "vlanCompOffLimit", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "vlan_comp_on_limit": MoPropertyMeta("vlan_comp_on_limit", "vlanCompOnLimit", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
    }

    prop_map = {
        "accessVlanPortCount": "access_vlan_port_count", 
        "allocStatus": "alloc_status", 
        "borderVlanPortCount": "border_vlan_port_count", 
        "childAction": "child_action", 
        "compressedOptimizationSets": "compressed_optimization_sets", 
        "compressedVlanPortCount": "compressed_vlan_port_count", 
        "configStatus": "config_status", 
        "dn": "dn", 
        "limit": "limit", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "switchId": "switch_id", 
        "totalOptimizationSets": "total_optimization_sets", 
        "totalVlanPortCount": "total_vlan_port_count", 
        "uncompressedVlanPortCount": "uncompressed_vlan_port_count", 
        "vlanCompOffLimit": "vlan_comp_off_limit", 
        "vlanCompOnLimit": "vlan_comp_on_limit", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.access_vlan_port_count = None
        self.alloc_status = None
        self.border_vlan_port_count = None
        self.child_action = None
        self.compressed_optimization_sets = None
        self.compressed_vlan_port_count = None
        self.config_status = None
        self.limit = None
        self.sacl = None
        self.status = None
        self.switch_id = None
        self.total_optimization_sets = None
        self.total_vlan_port_count = None
        self.uncompressed_vlan_port_count = None
        self.vlan_comp_off_limit = None
        self.vlan_comp_on_limit = None

        ManagedObject.__init__(self, "SwVlanPortNs", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FirmwarePackItem ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FirmwarePackItemConsts:
    PRESENCE_MISSING = "missing"
    PRESENCE_PRESENT = "present"
    PRESENCE_UNKNOWN = "unknown"
    TYPE_ADAPTOR = "adaptor"
    TYPE_BLADE_BIOS = "blade-bios"
    TYPE_BLADE_CONTROLLER = "blade-controller"
    TYPE_BOARD_CONTROLLER = "board-controller"
    TYPE_CHASSIS_BOARD_CONTROLLER = "chassis-board-controller"
    TYPE_CMC = "cmc"
    TYPE_FI_SERVICE_PACK = "fi-service-pack"
    TYPE_FLEXFLASH_CONTROLLER = "flexflash-controller"
    TYPE_GRAPHICS_CARD = "graphics-card"
    TYPE_HOST_HBA = "host-hba"
    TYPE_HOST_HBA_OPTIONROM = "host-hba-optionrom"
    TYPE_HOST_NIC = "host-nic"
    TYPE_HOST_NIC_OPTIONROM = "host-nic-optionrom"
    TYPE_IOCARD = "iocard"
    TYPE_LOCAL_DISK = "local-disk"
    TYPE_MGMT_SERVICE_PACK = "mgmt-service-pack"
    TYPE_NVME_MSWITCH = "nvme-mswitch"
    TYPE_PERSISTENT_MEMORY_DIMM = "persistent-memory-dimm"
    TYPE_PLX_SWITCH = "plx-switch"
    TYPE_PSU = "psu"
    TYPE_SAS_EXP_REG_FW = "sas-exp-reg-fw"
    TYPE_SAS_EXPANDER = "sas-expander"
    TYPE_STORAGE_CONTROLLER = "storage-controller"
    TYPE_STORAGE_CONTROLLER_ONBOARD_DEVICE = "storage-controller-onboard-device"
    TYPE_STORAGE_CONTROLLER_ONBOARD_DEVICE_CPLD = "storage-controller-onboard-device-cpld"
    TYPE_STORAGE_DEV_BRIDGE = "storage-dev-bridge"
    TYPE_STORAGE_NODE_CONTROLLER = "storage-node-controller"
    TYPE_SWITCH_KERNEL = "switch-kernel"
    TYPE_SWITCH_SOFTWARE = "switch-software"
    TYPE_SYSTEM = "system"
    TYPE_UNSPECIFIED = "unspecified"


class FirmwarePackItem(ManagedObject):
    """This is FirmwarePackItem class."""

    consts = FirmwarePackItemConsts()
    naming_props = set(['hwVendor', 'hwModel', 'type'])

    mo_meta = MoMeta("FirmwarePackItem", "firmwarePackItem", "pack-image-[hw_vendor]|[hw_model]|[type]", VersionMeta.Version101e, "InputOutput", 0x1ff, [], ["admin"], ['firmwareBackupVersionHolder', 'firmwareCatalogPack', 'firmwareChassisPack', 'firmwareComputeHostPack', 'firmwareComputeMgmtPack', 'firmwareInfraPack'], ['faultInst'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "hw_model": MoPropertyMeta("hw_model", "hwModel", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []),
        "hw_vendor": MoPropertyMeta("hw_vendor", "hwVendor", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x10, 1, 510, None, [], []),
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["missing", "present", "unknown"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x80, None, None, None, ["adaptor", "blade-bios", "blade-controller", "board-controller", "chassis-board-controller", "cmc", "fi-service-pack", "flexflash-controller", "graphics-card", "host-hba", "host-hba-optionrom", "host-nic", "host-nic-optionrom", "iocard", "local-disk", "mgmt-service-pack", "nvme-mswitch", "persistent-memory-dimm", "plx-switch", "psu", "sas-exp-reg-fw", "sas-expander", "storage-controller", "storage-controller-onboard-device", "storage-controller-onboard-device-cpld", "storage-dev-bridge", "storage-node-controller", "switch-kernel", "switch-software", "system", "unspecified"], []),
        "version": MoPropertyMeta("version", "version", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, 0, 510, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "hwModel": "hw_model", 
        "hwVendor": "hw_vendor", 
        "presence": "presence", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
        "version": "version", 
    }

    def __init__(self, parent_mo_or_dn, hw_vendor, hw_model, type, **kwargs):
        self._dirty_mask = 0
        self.hw_vendor = hw_vendor
        self.hw_model = hw_model
        self.type = type
        self.child_action = None
        self.presence = None
        self.sacl = None
        self.status = None
        self.version = None

        ManagedObject.__init__(self, "FirmwarePackItem", parent_mo_or_dn, **kwargs)



"""This module contains the general information for SwSystemStatsHist ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SwSystemStatsHistConsts:
    CORRECTABLE_PARITY_ERROR_NOT_APPLICABLE = "not-applicable"
    CORRECTABLE_PARITY_ERROR_AVG_NOT_APPLICABLE = "not-applicable"
    CORRECTABLE_PARITY_ERROR_MAX_NOT_APPLICABLE = "not-applicable"
    CORRECTABLE_PARITY_ERROR_MIN_NOT_APPLICABLE = "not-applicable"
    KERNEL_MEM_FREE_NOT_APPLICABLE = "not-applicable"
    KERNEL_MEM_FREE_AVG_NOT_APPLICABLE = "not-applicable"
    KERNEL_MEM_FREE_MAX_NOT_APPLICABLE = "not-applicable"
    KERNEL_MEM_FREE_MIN_NOT_APPLICABLE = "not-applicable"
    KERNEL_MEM_TOTAL_NOT_APPLICABLE = "not-applicable"
    KERNEL_MEM_TOTAL_AVG_NOT_APPLICABLE = "not-applicable"
    KERNEL_MEM_TOTAL_MAX_NOT_APPLICABLE = "not-applicable"
    KERNEL_MEM_TOTAL_MIN_NOT_APPLICABLE = "not-applicable"
    MOST_RECENT_FALSE = "false"
    MOST_RECENT_NO = "no"
    MOST_RECENT_TRUE = "true"
    MOST_RECENT_YES = "yes"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class SwSystemStatsHist(ManagedObject):
    """This is SwSystemStatsHist class."""

    consts = SwSystemStatsHistConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("SwSystemStatsHist", "swSystemStatsHist", "[id]", VersionMeta.Version111j, "OutputOnly", 0xf, [], ["read-only"], ['swSystemStats'], [], ["Get"])

    prop_meta = {
        "correctable_parity_error": MoPropertyMeta("correctable_parity_error", "CorrectableParityError", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "correctable_parity_error_avg": MoPropertyMeta("correctable_parity_error_avg", "CorrectableParityErrorAvg", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "correctable_parity_error_max": MoPropertyMeta("correctable_parity_error_max", "CorrectableParityErrorMax", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "correctable_parity_error_min": MoPropertyMeta("correctable_parity_error_min", "CorrectableParityErrorMin", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version111j, MoPropertyMeta.NAMING, None, None, None, None, [], []),
        "kernel_mem_free": MoPropertyMeta("kernel_mem_free", "kernelMemFree", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "kernel_mem_free_avg": MoPropertyMeta("kernel_mem_free_avg", "kernelMemFreeAvg", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "kernel_mem_free_max": MoPropertyMeta("kernel_mem_free_max", "kernelMemFreeMax", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "kernel_mem_free_min": MoPropertyMeta("kernel_mem_free_min", "kernelMemFreeMin", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "kernel_mem_total": MoPropertyMeta("kernel_mem_total", "kernelMemTotal", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "kernel_mem_total_avg": MoPropertyMeta("kernel_mem_total_avg", "kernelMemTotalAvg", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "kernel_mem_total_max": MoPropertyMeta("kernel_mem_total_max", "kernelMemTotalMax", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "kernel_mem_total_min": MoPropertyMeta("kernel_mem_total_min", "kernelMemTotalMin", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]),
        "load": MoPropertyMeta("load", "load", "float", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_avg": MoPropertyMeta("load_avg", "loadAvg", "float", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_max": MoPropertyMeta("load_max", "loadMax", "float", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_min": MoPropertyMeta("load_min", "loadMin", "float", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_available": MoPropertyMeta("mem_available", "memAvailable", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_available_avg": MoPropertyMeta("mem_available_avg", "memAvailableAvg", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_available_max": MoPropertyMeta("mem_available_max", "memAvailableMax", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_available_min": MoPropertyMeta("mem_available_min", "memAvailableMin", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_cached": MoPropertyMeta("mem_cached", "memCached", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_cached_avg": MoPropertyMeta("mem_cached_avg", "memCachedAvg", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_cached_max": MoPropertyMeta("mem_cached_max", "memCachedMax", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_cached_min": MoPropertyMeta("mem_cached_min", "memCachedMin", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "most_recent": MoPropertyMeta("most_recent", "mostRecent", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
    }

    prop_map = {
        "CorrectableParityError": "correctable_parity_error", 
        "CorrectableParityErrorAvg": "correctable_parity_error_avg", 
        "CorrectableParityErrorMax": "correctable_parity_error_max", 
        "CorrectableParityErrorMin": "correctable_parity_error_min", 
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "kernelMemFree": "kernel_mem_free", 
        "kernelMemFreeAvg": "kernel_mem_free_avg", 
        "kernelMemFreeMax": "kernel_mem_free_max", 
        "kernelMemFreeMin": "kernel_mem_free_min", 
        "kernelMemTotal": "kernel_mem_total", 
        "kernelMemTotalAvg": "kernel_mem_total_avg", 
        "kernelMemTotalMax": "kernel_mem_total_max", 
        "kernelMemTotalMin": "kernel_mem_total_min", 
        "load": "load", 
        "loadAvg": "load_avg", 
        "loadMax": "load_max", 
        "loadMin": "load_min", 
        "memAvailable": "mem_available", 
        "memAvailableAvg": "mem_available_avg", 
        "memAvailableMax": "mem_available_max", 
        "memAvailableMin": "mem_available_min", 
        "memCached": "mem_cached", 
        "memCachedAvg": "mem_cached_avg", 
        "memCachedMax": "mem_cached_max", 
        "memCachedMin": "mem_cached_min", 
        "mostRecent": "most_recent", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.correctable_parity_error = None
        self.correctable_parity_error_avg = None
        self.correctable_parity_error_max = None
        self.correctable_parity_error_min = None
        self.child_action = None
        self.kernel_mem_free = None
        self.kernel_mem_free_avg = None
        self.kernel_mem_free_max = None
        self.kernel_mem_free_min = None
        self.kernel_mem_total = None
        self.kernel_mem_total_avg = None
        self.kernel_mem_total_max = None
        self.kernel_mem_total_min = None
        self.load = None
        self.load_avg = None
        self.load_max = None
        self.load_min = None
        self.mem_available = None
        self.mem_available_avg = None
        self.mem_available_max = None
        self.mem_available_min = None
        self.mem_cached = None
        self.mem_cached_avg = None
        self.mem_cached_max = None
        self.mem_cached_min = None
        self.most_recent = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None

        ManagedObject.__init__(self, "SwSystemStatsHist", parent_mo_or_dn, **kwargs)



"""This module contains the general information for OrgOrg ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class OrgOrgConsts:
    LEVEL_1 = "1"
    LEVEL_2 = "2"
    LEVEL_3 = "3"
    LEVEL_4 = "4"
    LEVEL_5 = "5"
    LEVEL_ROOT = "root"
    PERM_ACCESS_FALSE = "false"
    PERM_ACCESS_NO = "no"
    PERM_ACCESS_TRUE = "true"
    PERM_ACCESS_YES = "yes"


class OrgOrg(ManagedObject):
    """This is OrgOrg class."""

    consts = OrgOrgConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("OrgOrg", "orgOrg", "org-[name]", VersionMeta.Version101e, "InputOutput", 0x7f, [], ["admin", "org-management"], ['orgOrg'], ['aaaEpAuthProfile', 'adaptorHostEthIfProfile', 'adaptorHostFcIfProfile', 'adaptorHostIscsiIfProfile', 'biosVProfile', 'cimcvmediaMountConfigPolicy', 'commSvcPolicy', 'computeAutoconfigPolicy', 'computeBladeDiscPolicy', 'computeBladeInheritPolicy', 'computeChassisConnPolicy', 'computeChassisDiscPolicy', 'computeFanPolicy', 'computeGraphicsCardPolicy', 'computeHwChangeDiscPolicy', 'computeKvmMgmtPolicy', 'computeMemoryConfigPolicy', 'computePool', 'computePoolingPolicy', 'computePortDiscPolicy', 'computePowerSavePolicy', 'computePowerSyncPolicy', 'computePsuPolicy', 'computeQual', 'computeRackConnLinkPolicy', 'computeScrubPolicy', 'computeServerDiscPolicy', 'computeServerMgmtPolicy', 'cpmaintMaintPolicy', 'diagRunPolicy', 'epqosDefinition', 'epqosDefinitionDelTask', 'equipmentAutoconfigPolicy', 'equipmentChassisInheritPolicy', 'equipmentChassisProfile', 'equipmentComputeConnPolicy', 'equipmentPool', 'equipmentPoolingPolicy', 'equipmentQual', 'equipmentTier', 'fabricLacpPolicy', 'fabricLanCloudPolicy', 'fabricMulticastPolicy', 'fabricOrgVlanPolicy', 'fabricUdldPolicy', 'fabricVConProfile', 'fabricVlanGroupPermit', 'fabricVlanGroupReq', 'fabricVlanPermit', 'fabricVlanReq', 'faultSuppressTask', 'fcpoolInitiators', 'firmwareAutoSyncPolicy', 'firmwareCatalogPack', 'firmwareChassisPack', 'firmwareComputeHostPack', 'firmwareComputeMgmtPack', 'firmwareInfraPack', 'hostimgPolicy', 'imgprovPolicy', 'imgsecPolicy', 'ippoolPool', 'iqnpoolPool', 'iscsiAuthProfile', 'lsAgentPolicy', 'lsServer', 'lsTier', 'lsbootPolicy', 'lsmaintMaintPolicy', 'lstorageDiskGroupConfigPolicy', 'lstorageDiskZoningPolicy', 'lstorageProfile', 'lstorageSasExpanderConfigPolicy', 'macpoolPool', 'memoryPersistentMemoryPolicy', 'mgmtBackupExportExtPolicy', 'mgmtBackupPolicy', 'mgmtCfgExportPolicy', 'mgmtSpdmCertificatePolicy', 'moKvCfgHolder', 'nwctrlDefinition', 'orgOrg', 'orgSourceMask', 'powerGroupAdditionPolicy', 'powerMgmtPolicy', 'powerPlacement', 'powerPolicy', 'solPolicy', 'statsThresholdPolicy', 'storageConnectionPolicy', 'storageLocalDiskConfigPolicy', 'sysdebugMEpLogPolicy', 'topInfoSyncPolicy', 'trigTest', 'uuidpoolPool', 'vmLifeCyclePolicy', 'vnicDynamicConPolicy', 'vnicFcGroupTempl', 'vnicIScsiInitAutoConfigPolicy', 'vnicLanConnPolicy', 'vnicLanConnTempl', 'vnicSanConnPolicy', 'vnicSanConnTempl', 'vnicUsnicConPolicy', 'vnicVhbaBehPolicy', 'vnicVmqConPolicy', 'vnicVnicBehPolicy'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, None, None, None, None, [], []),
        "level": MoPropertyMeta("level", "level", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["1", "2", "3", "4", "5", "root"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "perm_access": MoPropertyMeta("perm_access", "permAccess", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "fltAggr": "flt_aggr", 
        "level": "level", 
        "name": "name", 
        "permAccess": "perm_access", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.flt_aggr = None
        self.level = None
        self.perm_access = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "OrgOrg", parent_mo_or_dn, **kwargs)



"""This module contains the general information for CommDateTime ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class CommDateTimeConsts:
    ADMIN_STATE_DISABLED = "disabled"
    ADMIN_STATE_ENABLED = "enabled"
    CONFIG_STATE_FAILURE = "failure"
    CONFIG_STATE_SUCCESS = "success"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    PROTO_ALL = "all"
    PROTO_NONE = "none"
    PROTO_TCP = "tcp"
    PROTO_UDP = "udp"


class CommDateTime(ManagedObject):
    """This is CommDateTime class."""

    consts = CommDateTimeConsts()
    naming_props = set([])

    mo_meta = MoMeta("CommDateTime", "commDateTime", "datetime-svc", VersionMeta.Version101e, "InputOutput", 0x7ff, [], ["admin", "ext-lan-config", "ext-lan-security", "operations"], ['commLocale', 'commSvcEp', 'commSvcPolicy'], ['commNtpProvider', 'faultInst'], ["Get", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["disabled", "enabled"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["failure", "success"], []),
        "date": MoPropertyMeta("date", "date", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.CREATE_ONLY, 0x20, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_port": MoPropertyMeta("oper_port", "operPort", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-65535"]),
        "oper_timezone": MoPropertyMeta("oper_timezone", "operTimezone", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["local", "pending-policy", "policy"], []),
        "port": MoPropertyMeta("port", "port", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, [], ["0-65535"]),
        "proto": MoPropertyMeta("proto", "proto", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["all", "none", "tcp", "udp"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "timezone": MoPropertyMeta("timezone", "timezone", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x400, 0, 510, None, [], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "configState": "config_state", 
        "date": "date", 
        "descr": "descr", 
        "dn": "dn", 
        "intId": "int_id", 
        "name": "name", 
        "operPort": "oper_port", 
        "operTimezone": "oper_timezone", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "port": "port", 
        "proto": "proto", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "timezone": "timezone", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_state = None
        self.child_action = None
        self.config_state = None
        self.date = None
        self.descr = None
        self.int_id = None
        self.name = None
        self.oper_port = None
        self.oper_timezone = None
        self.policy_level = None
        self.policy_owner = None
        self.port = None
        self.proto = None
        self.sacl = None
        self.status = None
        self.timezone = None

        ManagedObject.__init__(self, "CommDateTime", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ApeSetAdaptorFirmwareVersion ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeSetAdaptorFirmwareVersion", "apeSetAdaptorFirmwareVersion", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_adaptor_fw_version": MethodPropertyMeta("InAdaptorFwVersion", "inAdaptorFwVersion", "Xs:string", "Version142b", "Input", False),
    "in_adaptor_serial": MethodPropertyMeta("InAdaptorSerial", "inAdaptorSerial", "Xs:string", "Version142b", "Input", False),
}

prop_map = {
    "cookie": "cookie",
    "inAdaptorFwVersion": "in_adaptor_fw_version",
    "inAdaptorSerial": "in_adaptor_serial",
}



"""This module contains the general information for FaultLocalTypedHolder ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FaultLocalTypedHolderConsts:
    TYPE_ANY = "any"
    TYPE_CHASSIS_PROFILE = "chassis-profile"
    TYPE_CONFIGURATION = "configuration"
    TYPE_CONNECTIVITY = "connectivity"
    TYPE_ENVIRONMENTAL = "environmental"
    TYPE_EQUIPMENT = "equipment"
    TYPE_FORWARD = "forward"
    TYPE_FSM = "fsm"
    TYPE_GENERIC = "generic"
    TYPE_MANAGEMENT = "management"
    TYPE_NETWORK = "network"
    TYPE_OPERATIONAL = "operational"
    TYPE_SECURITY = "security"
    TYPE_SERVER = "server"
    TYPE_SYSDEBUG = "sysdebug"


class FaultLocalTypedHolder(ManagedObject):
    """This is FaultLocalTypedHolder class."""

    consts = FaultLocalTypedHolderConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("FaultLocalTypedHolder", "faultLocalTypedHolder", "type-[type]", VersionMeta.Version211a, "InputOutput", 0x3f, [], ["admin", "fault"], ['faultHolder'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "total_faults": MoPropertyMeta("total_faults", "totalFaults", "ulong", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, 0x20, None, None, None, ["any", "chassis-profile", "configuration", "connectivity", "environmental", "equipment", "forward", "fsm", "generic", "management", "network", "operational", "security", "server", "sysdebug"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "name": "name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "totalFaults": "total_faults", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.name = None
        self.sacl = None
        self.status = None
        self.total_faults = None

        ManagedObject.__init__(self, "FaultLocalTypedHolder", parent_mo_or_dn, **kwargs)



"""This module contains the general information for SwEtherPort ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SwEtherPortConsts:
    pass


class SwEtherPort(ManagedObject):
    """This is SwEtherPort class."""

    consts = SwEtherPortConsts()
    naming_props = set(['slotId', 'aggrPortId', 'portId'])

    mo_meta = MoMeta("SwEtherPort", "swEtherPort", "slot-[slot_id]-aggrport-[aggr_port_id]-port-[port_id]", VersionMeta.Version321d, "InputOutput", 0xff, [], ["admin"], ['swPortDiscover'], [], [None])

    prop_meta = {
        "aggr_port_id": MoPropertyMeta("aggr_port_id", "aggrPortId", "uint", VersionMeta.Version321d, MoPropertyMeta.NAMING, 0x2, None, None, None, [], ["1-64"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version321d, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "port_id": MoPropertyMeta("port_id", "portId", "uint", VersionMeta.Version321d, MoPropertyMeta.NAMING, 0x10, None, None, None, [], ["1-64"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "slot_id": MoPropertyMeta("slot_id", "slotId", "uint", VersionMeta.Version321d, MoPropertyMeta.NAMING, 0x40, None, None, None, [], ["1-7"]),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "aggrPortId": "aggr_port_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "portId": "port_id", 
        "rn": "rn", 
        "sacl": "sacl", 
        "slotId": "slot_id", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, slot_id, aggr_port_id, port_id, **kwargs):
        self._dirty_mask = 0
        self.slot_id = slot_id
        self.aggr_port_id = aggr_port_id
        self.port_id = port_id
        self.child_action = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "SwEtherPort", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of EquipmentInstantiateNTemplate ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("EquipmentInstantiateNTemplate", "equipmentInstantiateNTemplate", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "dn": MethodPropertyMeta("Dn", "dn", "ReferenceObject", "Version142b", "InputOutput", False),
    "in_chassis_profile_name_prefix_or_empty": MethodPropertyMeta("InChassisProfileNamePrefixOrEmpty", "inChassisProfileNamePrefixOrEmpty", "Xs:string", "Version142b", "Input", False),
    "in_hierarchical": MethodPropertyMeta("InHierarchical", "inHierarchical", "Xs:string", "Version142b", "Input", False),
    "in_number_of": MethodPropertyMeta("InNumberOf", "inNumberOf", "Xs:unsignedByte", "Version142b", "Input", False),
    "in_target_org": MethodPropertyMeta("InTargetOrg", "inTargetOrg", "ReferenceObject", "Version142b", "Input", False),
    "out_configs": MethodPropertyMeta("OutConfigs", "outConfigs", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "dn": "dn",
    "inChassisProfileNamePrefixOrEmpty": "in_chassis_profile_name_prefix_or_empty",
    "inHierarchical": "in_hierarchical",
    "inNumberOf": "in_number_of",
    "inTargetOrg": "in_target_org",
    "outConfigs": "out_configs",
}



"""This module contains the general information for NetworkSanNeighborEntry ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class NetworkSanNeighborEntryConsts:
    pass


class NetworkSanNeighborEntry(ManagedObject):
    """This is NetworkSanNeighborEntry class."""

    consts = NetworkSanNeighborEntryConsts()
    naming_props = set(['localInterface'])

    mo_meta = MoMeta("NetworkSanNeighborEntry", "networkSanNeighborEntry", "if-[local_interface]", VersionMeta.Version223a, "InputOutput", 0x3f, [], ["read-only"], ['networkSanNeighbors'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version223a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "fabric_mgmt_addr": MoPropertyMeta("fabric_mgmt_addr", "fabricMgmtAddr", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "fabric_nwwn": MoPropertyMeta("fabric_nwwn", "fabricNwwn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "fabric_pwwn": MoPropertyMeta("fabric_pwwn", "fabricPwwn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "fi_port_dn": MoPropertyMeta("fi_port_dn", "fiPortDn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "local_interface": MoPropertyMeta("local_interface", "localInterface", "string", VersionMeta.Version223a, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []),
        "my_nwwn": MoPropertyMeta("my_nwwn", "myNwwn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "my_pwwn": MoPropertyMeta("my_pwwn", "myPwwn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "port_vsan": MoPropertyMeta("port_vsan", "portVsan", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version223a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "fabricMgmtAddr": "fabric_mgmt_addr", 
        "fabricNwwn": "fabric_nwwn", 
        "fabricPwwn": "fabric_pwwn", 
        "fiPortDn": "fi_port_dn", 
        "localInterface": "local_interface", 
        "myNwwn": "my_nwwn", 
        "myPwwn": "my_pwwn", 
        "portVsan": "port_vsan", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, local_interface, **kwargs):
        self._dirty_mask = 0
        self.local_interface = local_interface
        self.child_action = None
        self.fabric_mgmt_addr = None
        self.fabric_nwwn = None
        self.fabric_pwwn = None
        self.fi_port_dn = None
        self.my_nwwn = None
        self.my_pwwn = None
        self.port_vsan = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "NetworkSanNeighborEntry", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ApeSwitchFirmwareInv ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ApeSwitchFirmwareInvConsts:
    FABRIC_A = "A"
    FABRIC_B = "B"
    FABRIC_NONE = "NONE"


class ApeSwitchFirmwareInv(ManagedObject):
    """This is ApeSwitchFirmwareInv class."""

    consts = ApeSwitchFirmwareInvConsts()
    naming_props = set(['fabric'])

    mo_meta = MoMeta("ApeSwitchFirmwareInv", "apeSwitchFirmwareInv", "SwitchFirmwareInv-[fabric]", VersionMeta.Version131c, "InputOutput", 0xfff, [], ["read-only"], ['apeDcosAgManager'], [], [None])

    prop_meta = {
        "bios_version": MoPropertyMeta("bios_version", "biosVersion", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x2, 0, 510, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131c, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "fabric": MoPropertyMeta("fabric", "fabric", "string", VersionMeta.Version131c, MoPropertyMeta.NAMING, 0x10, None, None, None, ["A", "B", "NONE"], []),
        "ks_startup_version": MoPropertyMeta("ks_startup_version", "ksStartupVersion", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x20, 0, 510, None, [], []),
        "ks_version": MoPropertyMeta("ks_version", "ksVersion", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x40, 0, 510, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "sys_startup_version": MoPropertyMeta("sys_startup_version", "sysStartupVersion", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x400, 0, 510, None, [], []),
        "sys_version": MoPropertyMeta("sys_version", "sysVersion", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x800, 0, 510, None, [], []),
    }

    prop_map = {
        "biosVersion": "bios_version", 
        "childAction": "child_action", 
        "dn": "dn", 
        "fabric": "fabric", 
        "ksStartupVersion": "ks_startup_version", 
        "ksVersion": "ks_version", 
        "name": "name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "sysStartupVersion": "sys_startup_version", 
        "sysVersion": "sys_version", 
    }

    def __init__(self, parent_mo_or_dn, fabric, **kwargs):
        self._dirty_mask = 0
        self.fabric = fabric
        self.bios_version = None
        self.child_action = None
        self.ks_startup_version = None
        self.ks_version = None
        self.name = None
        self.sacl = None
        self.status = None
        self.sys_startup_version = None
        self.sys_version = None

        ManagedObject.__init__(self, "ApeSwitchFirmwareInv", parent_mo_or_dn, **kwargs)



"""This module contains the general information for NetworkElement ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class NetworkElementConsts:
    ADMIN_EVAC_STATE_DRAIN = "drain"
    ADMIN_EVAC_STATE_FILL = "fill"
    ADMIN_EVAC_STATE_UNKNOWN = "unknown"
    ADMIN_INBAND_IF_STATE_DISABLE = "disable"
    ADMIN_INBAND_IF_STATE_ENABLE = "enable"
    FORCE_EVAC_FALSE = "false"
    FORCE_EVAC_NO = "no"
    FORCE_EVAC_TRUE = "true"
    FORCE_EVAC_YES = "yes"
    ID_A = "A"
    ID_B = "B"
    ID_NONE = "NONE"
    OPER_EVAC_STATE_DRAIN = "drain"
    OPER_EVAC_STATE_FILL = "fill"
    OPER_EVAC_STATE_UNKNOWN = "unknown"
    OPERABILITY_DEPRECATED = "deprecated"
    OPERABILITY_INOPERABLE = "inoperable"
    OPERABILITY_OPERABLE = "operable"
    OPERABILITY_REMOVED = "removed"
    OPERABILITY_UNKNOWN = "unknown"
    SHUTDOWN_FAN_REMOVEAL_FALSE = "false"
    SHUTDOWN_FAN_REMOVEAL_NO = "no"
    SHUTDOWN_FAN_REMOVEAL_TRUE = "true"
    SHUTDOWN_FAN_REMOVEAL_YES = "yes"
    THERMAL_LOWER_CRITICAL = "lower-critical"
    THERMAL_LOWER_NON_CRITICAL = "lower-non-critical"
    THERMAL_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    THERMAL_NOT_SUPPORTED = "not-supported"
    THERMAL_OK = "ok"
    THERMAL_UNKNOWN = "unknown"
    THERMAL_UPPER_CRITICAL = "upper-critical"
    THERMAL_UPPER_NON_CRITICAL = "upper-non-critical"
    THERMAL_UPPER_NON_RECOVERABLE = "upper-non-recoverable"


class NetworkElement(ManagedObject):
    """This is NetworkElement class."""

    consts = NetworkElementConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("NetworkElement", "networkElement", "switch-[id]", VersionMeta.Version101e, "InputOutput", 0x7ff, [], ["admin", "ext-lan-config"], ['topSystem'], ['equipmentFan', 'equipmentFanModule', 'equipmentLocatorLed', 'equipmentPsu', 'equipmentSwitchCard', 'extmgmtIf', 'faultInst', 'fcpoolOuis', 'firmwareSecureFPGA', 'firmwareStatus', 'mgmtController', 'mgmtDbState', 'mgmtHealthStatus', 'mgmtIPv6IfConfig', 'networkLanNeighbors', 'networkLimit', 'networkLldpNeighbors', 'networkOperLevel', 'networkSanNeighbors', 'nfsMountInst', 'powerBudget', 'storageItem', 'swAccessDomain', 'swCardEnvStats', 'swEnvStats', 'swEthLanBorder', 'swEthLanFlowMon', 'swEthLanMon', 'swExtUtility', 'swFabricZoneNs', 'swFcSanBorder', 'swFcSanMon', 'swPhys', 'swPortDiscover', 'swSystemStats', 'swUtilityDomain', 'swVlanPortNs'], ["Get", "Set"])

    prop_meta = {
        "admin_evac_state": MoPropertyMeta("admin_evac_state", "adminEvacState", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["drain", "fill", "unknown"], []),
        "admin_inband_if_state": MoPropertyMeta("admin_inband_if_state", "adminInbandIfState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disable", "enable"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "diff_memory": MoPropertyMeta("diff_memory", "diffMemory", "uint", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "expected_memory": MoPropertyMeta("expected_memory", "expectedMemory", "uint", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, None, None, None, None, [], []),
        "force_evac": MoPropertyMeta("force_evac", "forceEvac", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["false", "no", "true", "yes"], []),
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x20, None, None, None, ["A", "B", "NONE"], []),
        "inband_if_gw": MoPropertyMeta("inband_if_gw", "inbandIfGw", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "inband_if_ip": MoPropertyMeta("inband_if_ip", "inbandIfIp", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "inband_if_mask": MoPropertyMeta("inband_if_mask", "inbandIfMask", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "inband_if_vnet": MoPropertyMeta("inband_if_vnet", "inbandIfVnet", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4090"]),
        "inventory_status": MoPropertyMeta("inventory_status", "inventoryStatus", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|up|remote-eth-port-inventory|fc-pc-inventory|fc-port-inventory|switch-fru|vlan-comp-grp-inventory|switch-inventory|vlan-port-count|mgmt-port-inventory|card-inventory|xcvr-inventory|eth-pc-inventory|eth-port-inventory),){0,13}(defaultValue|up|remote-eth-port-inventory|fc-pc-inventory|fc-port-inventory|switch-fru|vlan-comp-grp-inventory|switch-inventory|vlan-port-count|mgmt-port-inventory|card-inventory|xcvr-inventory|eth-pc-inventory|eth-port-inventory){0,1}""", [], []),
        "min_active_fan": MoPropertyMeta("min_active_fan", "minActiveFan", "ushort", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-65535"]),
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "oob_if_gw": MoPropertyMeta("oob_if_gw", "oobIfGw", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "oob_if_ip": MoPropertyMeta("oob_if_ip", "oobIfIp", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x80, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "oob_if_mac": MoPropertyMeta("oob_if_mac", "oobIfMac", "string", VersionMeta.Version226c, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "oob_if_mask": MoPropertyMeta("oob_if_mask", "oobIfMask", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "oper_evac_state": MoPropertyMeta("oper_evac_state", "operEvacState", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["drain", "fill", "unknown"], []),
        "operability": MoPropertyMeta("operability", "operability", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["deprecated", "inoperable", "operable", "removed", "unknown"], []),
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x200, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "shutdown_fan_removeal": MoPropertyMeta("shutdown_fan_removeal", "shutdownFanRemoveal", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "thermal": MoPropertyMeta("thermal", "thermal", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
        "total_memory": MoPropertyMeta("total_memory", "totalMemory", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "adminEvacState": "admin_evac_state", 
        "adminInbandIfState": "admin_inband_if_state", 
        "childAction": "child_action", 
        "diffMemory": "diff_memory", 
        "dn": "dn", 
        "expectedMemory": "expected_memory", 
        "fltAggr": "flt_aggr", 
        "forceEvac": "force_evac", 
        "id": "id", 
        "inbandIfGw": "inband_if_gw", 
        "inbandIfIp": "inband_if_ip", 
        "inbandIfMask": "inband_if_mask", 
        "inbandIfVnet": "inband_if_vnet", 
        "inventoryStatus": "inventory_status", 
        "minActiveFan": "min_active_fan", 
        "model": "model", 
        "oobIfGw": "oob_if_gw", 
        "oobIfIp": "oob_if_ip", 
        "oobIfMac": "oob_if_mac", 
        "oobIfMask": "oob_if_mask", 
        "operEvacState": "oper_evac_state", 
        "operability": "operability", 
        "revision": "revision", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serial": "serial", 
        "shutdownFanRemoveal": "shutdown_fan_removeal", 
        "status": "status", 
        "thermal": "thermal", 
        "totalMemory": "total_memory", 
        "vendor": "vendor", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.admin_evac_state = None
        self.admin_inband_if_state = None
        self.child_action = None
        self.diff_memory = None
        self.expected_memory = None
        self.flt_aggr = None
        self.force_evac = None
        self.inband_if_gw = None
        self.inband_if_ip = None
        self.inband_if_mask = None
        self.inband_if_vnet = None
        self.inventory_status = None
        self.min_active_fan = None
        self.model = None
        self.oob_if_gw = None
        self.oob_if_ip = None
        self.oob_if_mac = None
        self.oob_if_mask = None
        self.oper_evac_state = None
        self.operability = None
        self.revision = None
        self.sacl = None
        self.serial = None
        self.shutdown_fan_removeal = None
        self.status = None
        self.thermal = None
        self.total_memory = None
        self.vendor = None

        ManagedObject.__init__(self, "NetworkElement", parent_mo_or_dn, **kwargs)



"""This module contains the general information for VnicIScsiStaticTargetIf ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class VnicIScsiStaticTargetIfConsts:
    pass


class VnicIScsiStaticTargetIf(ManagedObject):
    """This is VnicIScsiStaticTargetIf class."""

    consts = VnicIScsiStaticTargetIfConsts()
    naming_props = set(['priority'])

    mo_meta = MoMeta("VnicIScsiStaticTargetIf", "vnicIScsiStaticTargetIf", "[priority]", VersionMeta.Version201m, "InputOutput", 0x3ff, [], ["admin", "ls-config", "ls-network", "ls-server", "ls-storage"], ['adaptorVlan', 'vnicIScsi', 'vnicIScsiBootVnic', 'vnicVlan'], ['faultInst', 'vnicLun'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "auth_profile_name": MoPropertyMeta("auth_profile_name", "authProfileName", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "ip_address": MoPropertyMeta("ip_address", "ipAddress", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x10, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""[0-9a-zA-Z\.:-]{0,223}""", [], []),
        "oper_auth_profile_name": MoPropertyMeta("oper_auth_profile_name", "operAuthProfileName", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "port": MoPropertyMeta("port", "port", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], ["1-65535"]),
        "priority": MoPropertyMeta("priority", "priority", "ushort", VersionMeta.Version201m, MoPropertyMeta.NAMING, 0x80, None, None, None, [], ["1-2"]),
        "prop_acl": MoPropertyMeta("prop_acl", "propAcl", "ulong", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "authProfileName": "auth_profile_name", 
        "childAction": "child_action", 
        "dn": "dn", 
        "ipAddress": "ip_address", 
        "name": "name", 
        "operAuthProfileName": "oper_auth_profile_name", 
        "port": "port", 
        "priority": "priority", 
        "propAcl": "prop_acl", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, priority, **kwargs):
        self._dirty_mask = 0
        self.priority = priority
        self.auth_profile_name = None
        self.child_action = None
        self.ip_address = None
        self.name = None
        self.oper_auth_profile_name = None
        self.port = None
        self.prop_acl = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "VnicIScsiStaticTargetIf", parent_mo_or_dn, **kwargs)



"""This module contains the general information for StorageVirtualDriveRef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class StorageVirtualDriveRefConsts:
    ADMIN_STATE_OFFLINE = "offline"
    ADMIN_STATE_ONLINE = "online"
    ADMIN_STATE_UNDEPLOYED = "undeployed"
    CONFIG_STATE_N_A = "N/A"
    CONFIG_STATE_APPLIED = "applied"
    CONFIG_STATE_APPLY_FAILED = "apply-failed"
    CONFIG_STATE_APPLYING = "applying"
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    CONFIG_STATE_NOT_IN_USE = "not-in-use"
    CONFIG_STATE_ORPHANED = "orphaned"
    CONFIG_STATE_UNKNOWN = "unknown"
    IS_BOOTABLE_DISABLED = "disabled"
    IS_BOOTABLE_ENABLED = "enabled"
    ORDER_NOT_APPLICABLE = "not-applicable"
    RAID_LEVEL_MIRROR = "mirror"
    RAID_LEVEL_MIRROR_STRIPE = "mirror-stripe"
    RAID_LEVEL_RAID = "raid"
    RAID_LEVEL_SIMPLE = "simple"
    RAID_LEVEL_STRIPE = "stripe"
    RAID_LEVEL_STRIPE_DUAL_PARITY = "stripe-dual-parity"
    RAID_LEVEL_STRIPE_DUAL_PARITY_STRIPE = "stripe-dual-parity-stripe"
    RAID_LEVEL_STRIPE_PARITY = "stripe-parity"
    RAID_LEVEL_STRIPE_PARITY_STRIPE = "stripe-parity-stripe"
    RAID_LEVEL_UNSPECIFIED = "unspecified"


class StorageVirtualDriveRef(ManagedObject):
    """This is StorageVirtualDriveRef class."""

    consts = StorageVirtualDriveRefConsts()
    naming_props = set(['lunItemName'])

    mo_meta = MoMeta("StorageVirtualDriveRef", "storageVirtualDriveRef", "vdrive-ref-[lun_item_name]", VersionMeta.Version224b, "InputOutput", 0x1ff, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-storage"], ['lsServer'], ['lstorageDiskGroupConfigDef', 'storageLunResourceSelectionLog'], ["Get"])

    prop_meta = {
        "admin_name": MoPropertyMeta("admin_name", "adminName", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x2, 0, 10, None, [], []),
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["offline", "online", "undeployed"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version224b, MoPropertyMeta.INTERNAL, 0x8, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A", "applied", "apply-failed", "applying", "not-applied", "not-in-use", "orphaned", "unknown"], []),
        "disk_selection_order": MoPropertyMeta("disk_selection_order", "diskSelectionOrder", "ushort", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "disk_selection_ts": MoPropertyMeta("disk_selection_ts", "diskSelectionTs", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "is_bootable": MoPropertyMeta("is_bootable", "isBootable", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disabled", "enabled"], []),
        "lun_dn": MoPropertyMeta("lun_dn", "lunDn", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "lun_item_dn": MoPropertyMeta("lun_item_dn", "lunItemDn", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "lun_item_name": MoPropertyMeta("lun_item_name", "lunItemName", "string", VersionMeta.Version224b, MoPropertyMeta.NAMING, 0x20, 1, 32, None, [], []),
        "lun_name": MoPropertyMeta("lun_name", "lunName", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{0,15}""", [], []),
        "lun_set_disk_slot_id": MoPropertyMeta("lun_set_disk_slot_id", "lunSetDiskSlotId", "uint", VersionMeta.Version402a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["1-60"]),
        "order": MoPropertyMeta("order", "order", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-64"]),
        "raid_level": MoPropertyMeta("raid_level", "raidLevel", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["mirror", "mirror-stripe", "raid", "simple", "stripe", "stripe-dual-parity", "stripe-dual-parity-stripe", "stripe-parity", "stripe-parity-stripe", "unspecified"], []),
        "ref_lun_set": MoPropertyMeta("ref_lun_set", "refLunSet", "string", VersionMeta.Version402a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "size": MoPropertyMeta("size", "size", "ulong", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "uuid": MoPropertyMeta("uuid", "uuid", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([0-9a-fA-F]){8}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){12})|0""", [], []),
        "vendor_uuid": MoPropertyMeta("vendor_uuid", "vendorUuid", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([0-9a-fA-F]){8}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){12})|0""", [], []),
    }

    prop_map = {
        "adminName": "admin_name", 
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "configState": "config_state", 
        "diskSelectionOrder": "disk_selection_order", 
        "diskSelectionTs": "disk_selection_ts", 
        "dn": "dn", 
        "isBootable": "is_bootable", 
        "lunDn": "lun_dn", 
        "lunItemDn": "lun_item_dn", 
        "lunItemName": "lun_item_name", 
        "lunName": "lun_name", 
        "lunSetDiskSlotId": "lun_set_disk_slot_id", 
        "order": "order", 
        "raidLevel": "raid_level", 
        "refLunSet": "ref_lun_set", 
        "rn": "rn", 
        "sacl": "sacl", 
        "size": "size", 
        "status": "status", 
        "uuid": "uuid", 
        "vendorUuid": "vendor_uuid", 
    }

    def __init__(self, parent_mo_or_dn, lun_item_name, **kwargs):
        self._dirty_mask = 0
        self.lun_item_name = lun_item_name
        self.admin_name = None
        self.admin_state = None
        self.child_action = None
        self.config_state = None
        self.disk_selection_order = None
        self.disk_selection_ts = None
        self.is_bootable = None
        self.lun_dn = None
        self.lun_item_dn = None
        self.lun_name = None
        self.lun_set_disk_slot_id = None
        self.order = None
        self.raid_level = None
        self.ref_lun_set = None
        self.sacl = None
        self.size = None
        self.status = None
        self.uuid = None
        self.vendor_uuid = None

        ManagedObject.__init__(self, "StorageVirtualDriveRef", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FabricNetflowCollector ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricNetflowCollectorConsts:
    FLOW_PROTOCOL_NETFLOW = "netflow"
    ID_A = "A"
    ID_B = "B"
    ID_NONE = "NONE"


class FabricNetflowCollector(ManagedObject):
    """This is FabricNetflowCollector class."""

    consts = FabricNetflowCollectorConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FabricNetflowCollector", "fabricNetflowCollector", "flow-collector-[name]", VersionMeta.Version221b, "InputOutput", 0x3ff, [], ["admin", "ext-lan-config", "ext-lan-policy"], ['fabricEthLanFlowMonitoring'], ['ipIpV4StaticTargetAddr'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version221b, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "flow_protocol": MoPropertyMeta("flow_protocol", "flowProtocol", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["netflow"], []),
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version221b, MoPropertyMeta.CREATE_ONLY, 0x10, None, None, None, ["A", "B", "NONE"], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version221b, MoPropertyMeta.NAMING, 0x20, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "port": MoPropertyMeta("port", "port", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], ["1-65535"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "source_vlan": MoPropertyMeta("source_vlan", "sourceVlan", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x100, 0, 510, None, [], []),
        "source_vlan_dn": MoPropertyMeta("source_vlan_dn", "sourceVlanDn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "flowProtocol": "flow_protocol", 
        "id": "id", 
        "locale": "locale", 
        "name": "name", 
        "port": "port", 
        "rn": "rn", 
        "sacl": "sacl", 
        "sourceVlan": "source_vlan", 
        "sourceVlanDn": "source_vlan_dn", 
        "status": "status", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.flow_protocol = None
        self.id = None
        self.locale = None
        self.port = None
        self.sacl = None
        self.source_vlan = None
        self.source_vlan_dn = None
        self.status = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "FabricNetflowCollector", parent_mo_or_dn, **kwargs)
